@@ -38,8 +38,6 @@ from mic.chroot import kill_proc_inchroot
 from mic.archive import get_archive_suffixes
 from mic.conf import configmgr
 from mic.utils.grabber import myurlgrab
-#post script max run time
-MAX_RUN_TIME = 120
 
 class BaseImageCreator(object):
     """Installs a system to a chroot directory.
@@ -1300,7 +1298,6 @@ class BaseImageCreator(object):
             else:
                 preexec = self._chroot
                 script = "/tmp/" + os.path.basename(path)
-
             start_time = time.time()
             try:
                 try:
@@ -1312,8 +1309,8 @@ class BaseImageCreator(object):
                     while p.poll() == None:
                     	msger.info(p.stdout.readline().strip())
                         end_time = time.time()
-                        if (end_time - start_time)/60 > MAX_RUN_TIME:
-                            raise CreatorError("Your post script is executed more than "+MAX_RUN_TIME+"mins, please check it!")
+                        if (end_time - start_time)/60 > configmgr.create['postscripts_maxruntime']:
+                            raise CreatorError("Your post script is executed more than %d mins, please check it!" % configmgr.create['postscripts_maxruntime'])
                     if p.returncode != 0:
                         raise CreatorError("Failed to execute %%post script "
                                            "with '%s'" % (s.interp))
