@@ -721,6 +721,8 @@ class Zypp(BackendPlugin):
             self.repo_manager.loadFromCache(repo)
 
         self.Z = zypp.ZYppFactory_instance().getZYpp()
+        #Don't install recommended packages.
+        self.Z.resolver().setOnlyRequires(True)
         self.Z.initializeTarget(zypp.Pathname(self.instroot))
         self.Z.target().load()
 
